============
Contributing
============

Contributions are welcome, and they are greatly appreciated!
Every little bit helps, and credit will always be given.
Have a look at the `great guide <https://docs.sunpy.org/en/latest/dev_guide/contents/newcomers.html>`_ from the `sunpy project <https://sunpy.org>`_ which provides advice for new contributors.

All contributors will be treated with respect and everyone is expected to comply with the SunPy `Code of Conduct <https://sunpy.org/coc>`_.
